#!/bin/bash

#PBS -k o
#PBS -l nodes=1:ppn=16
#PBS -l walltime=72:00:00
#PBS -N seed_contigs
#PBS -j oe

cd ~/class_data/

#####################################################
#####################################################

#  Variables to store information and settings about the current project

project_name=seed_contigs

original_assembly=initial_minia_assembly/minia_assembly.contigs.fa

reference=rickettsiella_grylli.fasta

#####################################################
#####################################################

mkdir rickettsiella_seed_contigs
cd rickettsiella_seed_contigs

module load BLAST2.28
module load samtools1.19
module load SOAPdenovo2

#BLAST all contigs from original assembly to Rickettsiella, get seed contigs

makeblastdb -in ../${reference} -dbtype nucl
blastn -outfmt "6 qseqid sseqid evalue bitscore length pident nident gaps qstart qend sstart send" -task blastn -db ../${reference} -query ../${original_assembly} -num_alignments 10 -evalue 1e-10 -out ${project_name}_blast_results.txt

bwa index ../${original_assembly}
for sex in M F
do
    reads1=../filtered_wgs_data/T_rath_${sex}_wgs_cleaned_1.fastq
    reads2=../filtered_wgs_data/T_rath_${sex}_wgs_cleaned_2.fastq
    bwa mem -t 16 ../${original_assembly} ${reads1} ${reads2} > mapped_${sex}.sam
    samtools view -b -S -t ../${original_assembly}.fai mapped_${sex}.sam -o mapped_${sex}_unsorted.bam
    samtools sort mapped_${sex}_unsorted.bam mapped_${sex}_sorted
    samtools index mapped_${sex}_sorted.bam
done

samtools depth mapped_F_sorted.bam mapped_M_sorted.bam > depth.txt

python ../get_average_contig_coverage.py depth.txt F_gDNA,M_gDNA > per_contig_coverage_data.txt

R --no-save --args ${project_name}_blast_results.txt < ../generate_seed_contigs.R

