#######################################
#Read in the BLAST results

column.titles <- c("qseqid",  "sseqid",  "evalue",  "bitscore", "length", "pident", "nident", "gaps", "qstart", "qend", "sstart", "send")
args <- commandArgs(trailingOnly = TRUE)
blast.results <- read.table(args[1], header=F, col.names=column.titles)

#Filter BLAST results
blast.results <- blast.results[blast.results$evalue < 1e-20,]
blast.results$qseqid <- as.character(blast.results$qseqid)
blast.results$sseqid <- as.character(blast.results$sseqid)

#Add contig length data column
tempcrap <- unlist(strsplit(blast.results$qseqid, split="__len__"))
blast.results$contig_len <- as.numeric(tempcrap[seq(from=2, to=length(tempcrap), by=2)])

#Further filter by length
blast.results <- blast.results[blast.results$contig_len >= 200,]

#######################################
#Read in the coverage data

cov.results <- read.csv("../rickettsiella_seed_contigs/per_contig_coverage_data.txt")

cov.results$contig <- as.character(cov.results$contig)

cov.results <- cov.results[cov.results$contig %in% blast.results$qseqid,]

#######################################
#Get coverage results for the Rickettsiella scaffolds

blast.results$contig_len <- rep(NA, nrow(blast.results))
blast.results$F_cov <- rep(NA, nrow(blast.results))
blast.results$M_cov <- rep(NA, nrow(blast.results))

for (r in 1:nrow(blast.results)) {
	cur.cov.row <- which(cov.results$contig == blast.results$qseqid[r])
	if (length(cur.cov.row) > 0) {
		blast.results$contig_len[r] <- cov.results$pos[cur.cov.row]
		blast.results$F_cov[r] <- cov.results$F_gDNA[cur.cov.row]
		blast.results$M_cov[r] <- cov.results$M_gDNA[cur.cov.row]
	}
}



###########################################

low.sim <- blast.results[(blast.results$F_cov >= 800),]

high.sim <- blast.results[(blast.results$F_cov <= 100),]

high.sim.unique <- high.sim[!duplicated(high.sim$qseqid),]
low.sim.unique <- low.sim[!duplicated(low.sim$qseqid),]

write.table(high.sim.unique$qseqid, file="high_similarity_contigs.txt", quote=F, col.names=F, row.names=F)
write.table(low.sim.unique$qseqid, file="low_similarity_contigs.txt", quote=F, col.names=F, row.names=F)

#sum(high.sim.unique$contig_len)
#sum(low.sim.unique$contig_len)