'''

Takes the coverage pileupcount file and gets average coverage of each contig in it

Usage:
python get_average_contig_coverage.py <pileupcountfile> <header>

The <header> should be a comma-delimited list of sample names, corresponding to the count
    columns in the <pileupcountfile>

'''

import sys

file = sys.argv[1]

header = sys.argv[2]

samples = header.split(',')
n_samples = len(samples)

file_handle = open(file, 'r')

print "contig,pos,%s" % header.strip()

#Splits the current line into its component fields
def split_line(cur_line):
    cur_fields = cur_line.strip().split("\t")
    return cur_fields

#Extracts the number of reads mapping to the current contig/position for each sample file
def get_counts(cur_fields):
    return [int(c) for c in cur_fields[2:(n_samples+2)]]

#Adds a number of mapped reads to the current cumulative totals for the current transcript
def increment_counts(totals, adds):
    for i in range(n_samples):
        totals[i] = totals[i] + adds[i]

#Initialize things
cur_fields = split_line(file_handle.readline())
sum_counts = get_counts(cur_fields)
last_fields = cur_fields

for cur_line in file_handle:
    #Read the next line
    cur_fields = split_line(cur_line)
    cur_counts = get_counts(cur_fields)
    #Are we still on the same transcript?
    if (cur_fields[0] == last_fields[0]):
        #If so, add the totals
        increment_counts(sum_counts, cur_counts)
    else:
        #If not, 'close out' the previous transcript and start a new one
        transcript_size = float(last_fields[1])
        coverages = [str(float(s)/transcript_size) for s in sum_counts]
        output_string = last_fields[0] + "," + last_fields[1] + "," + ",".join(coverages)
        print(output_string)
        sum_counts = cur_counts
    last_fields = cur_fields

#Now we have to close out the last one, or it will never get printed
transcript_size = float(last_fields[1])
coverages = [str(float(s)/transcript_size) for s in sum_counts]
output_string = last_fields[0] + "," + last_fields[1] + "," + ",".join(coverages)
print(output_string)
            
file_handle.close()
        