#!/bin/bash

#PBS -k o
#PBS -l nodes=1:ppn=16
#PBS -l walltime=120:00:00
#PBS -N iterative_rick_soap
#PBS -j oe

cd ~/class_data/

#####################################################
#####################################################

#  Variables to store information and settings about the current project

k=53
d1=2
d2=10
project_name=rickettsiella_soap_k${k}_d${d1}_d${d2}_v2

original_assembly=initial_minia_assembly/minia_assembly.contigs.fa

reference=rickettsiella_grylli.fasta

#####################################################
#####################################################

mkdir ${project_name}
cd ${project_name}

module load BLAST2.28
module load samtools1.19
module load SOAPdenovo2

#Iteration 0:
i=0
mkdir iteration${i}
cd iteration${i}

#Generate fasta file with seed conigs for each Rickettsiella strain

cp ../../rickettsiella_seed_contigs/high_similarity_contigs.txt .
cp ../../rickettsiella_seed_contigs/low_similarity_contigs.txt .

#Extract the seed contigs into separate assemblies, then merge them while re-name them for easier identification of reads mapping to each
python ../../extract_contigs.py high_similarity_contigs.txt ../../${original_assembly} > high_similarity_contigs.fasta
python ../../extract_contigs.py low_similarity_contigs.txt ../../${original_assembly} > low_similarity_contigs.fasta
sed 's/>/>high_similarity_/' high_similarity_contigs.fasta > merged_contigs.fasta
sed 's/>/>low_similarity_/' low_similarity_contigs.fasta >> merged_contigs.fasta

#Map reads to them and extract mapped reads & their mates
bwa index merged_contigs.fasta
for sex in M F
do
    reads1=../../filtered_wgs_data/T_rath_${sex}_wgs_cleaned_1.fastq
    reads2=../../filtered_wgs_data/T_rath_${sex}_wgs_cleaned_2.fastq
    bwa mem -t 16 merged_contigs.fasta ${reads1} ${reads2} | samtools view -S -F 256 -q 40 - > mapped_successful_${sex}.sam
    awk '{if (($3 ~ "high_similarity") && ($6 !~ "S")) {print $1}}' mapped_successful_${sex}.sam | uniq > high_similarity_reads_${sex}.reads
    seqtk subseq ${reads1} high_similarity_reads_${sex}.reads > high_similarity_reads_${sex}_1.fastq
    seqtk subseq ${reads2} high_similarity_reads_${sex}.reads > high_similarity_reads_${sex}_2.fastq
    awk '{if (($3 ~ "low_similarity") && ($6 !~ "S")) {print $1}}' mapped_successful_${sex}.sam | uniq > low_similarity_reads_${sex}.reads
    seqtk subseq ${reads1} low_similarity_reads_${sex}.reads > low_similarity_reads_${sex}_1.fastq
    seqtk subseq ${reads2} low_similarity_reads_${sex}.reads > low_similarity_reads_${sex}_2.fastq
done

#Assemble each
#high similarity Rickettsiella
echo 'max_rd_len=101' > CONFIG_FILE_HIGH
echo '[LIB]' >> CONFIG_FILE_HIGH
echo 'avg_ins=225' >> CONFIG_FILE_HIGH
echo 'reverse_seq=0' >> CONFIG_FILE_HIGH
echo 'asm_flags=3' >> CONFIG_FILE_HIGH
echo 'pair_num_cutoff=3' >> CONFIG_FILE_HIGH
echo 'rank=1' >> CONFIG_FILE_HIGH
echo 'q1=high_similarity_reads_M_1.fastq' >> CONFIG_FILE_HIGH
echo 'q2=high_similarity_reads_M_2.fastq' >> CONFIG_FILE_HIGH
# echo '[LIB]' >> CONFIG_FILE_HIGH
# echo 'avg_ins=225' >> CONFIG_FILE_HIGH
# echo 'reverse_seq=0' >> CONFIG_FILE_HIGH
# echo 'asm_flags=3' >> CONFIG_FILE_HIGH
# echo 'pair_num_cutoff=3' >> CONFIG_FILE_HIGH
# echo 'rank=1' >> CONFIG_FILE_HIGH
# echo 'q1=high_similarity_reads_F_1.fastq' >> CONFIG_FILE_HIGH
# echo 'q2=high_similarity_reads_F_2.fastq' >> CONFIG_FILE_HIGH
#Do the assembly
SOAPdenovo-63mer all -s CONFIG_FILE_HIGH -K ${k} -d ${d1} -o high_similarity -b 2.0 -B 0.5 -p 16 -N 1600000

#low similarity Rickettsiella
echo 'max_rd_len=101' > CONFIG_FILE_LOW
# echo '[LIB]' >> CONFIG_FILE_LOW
# echo 'avg_ins=225' >> CONFIG_FILE_LOW
# echo 'reverse_seq=0' >> CONFIG_FILE_LOW
# echo 'asm_flags=3' >> CONFIG_FILE_LOW
# echo 'pair_num_cutoff=3' >> CONFIG_FILE_LOW
# echo 'rank=1' >> CONFIG_FILE_LOW
# echo 'q1=low_similarity_reads_M_1.fastq' >> CONFIG_FILE_LOW
# echo 'q2=low_similarity_reads_M_2.fastq' >> CONFIG_FILE_LOW
echo '[LIB]' >> CONFIG_FILE_LOW
echo 'avg_ins=225' >> CONFIG_FILE_LOW
echo 'reverse_seq=0' >> CONFIG_FILE_LOW
echo 'asm_flags=3' >> CONFIG_FILE_LOW
echo 'pair_num_cutoff=3' >> CONFIG_FILE_LOW
echo 'rank=1' >> CONFIG_FILE_LOW
echo 'q1=low_similarity_reads_F_1.fastq' >> CONFIG_FILE_LOW
echo 'q2=low_similarity_reads_F_2.fastq' >> CONFIG_FILE_LOW
#Do the assembly
SOAPdenovo-63mer all -s CONFIG_FILE_LOW -K ${k} -d ${d2} -o low_similarity -b 2.0 -B 0.5 -p 16 -N 1600000


#Now repeat this
last_i=0
for i in 1 2 3 4 5 6 7 8 9 10
do
    cd ..
    mkdir iteration${i}
    cd iteration${i}
    #Merge the assemblies
    sed 's/>/>high_similarity_/' ../iteration${last_i}/high_similarity.scafSeq > merged_contigs.fasta
    sed 's/>/>low_similarity_/'  ../iteration${last_i}/low_similarity.scafSeq >> merged_contigs.fasta
    
    #Map reads to them and extract mapped reads & their mates
    bwa index merged_contigs.fasta
    for sex in M F
    do
        reads1=../../filtered_wgs_data/T_rath_${sex}_wgs_cleaned_1.fastq
        reads2=../../filtered_wgs_data/T_rath_${sex}_wgs_cleaned_2.fastq
        bwa mem -t 16 merged_contigs.fasta ${reads1} ${reads2} | samtools view -S -F 256 -q 40 - > mapped_successful_${sex}.sam
        awk '{if (($3 ~ "high_similarity") && ($6 !~ "S")) {print $1}}' mapped_successful_${sex}.sam | uniq > high_similarity_reads_${sex}.reads
        seqtk subseq ${reads1} high_similarity_reads_${sex}.reads > high_similarity_reads_${sex}_1.fastq
        seqtk subseq ${reads2} high_similarity_reads_${sex}.reads > high_similarity_reads_${sex}_2.fastq
        awk '{if (($3 ~ "low_similarity") && ($6 !~ "S")) {print $1}}' mapped_successful_${sex}.sam | uniq > low_similarity_reads_${sex}.reads
        seqtk subseq ${reads1} low_similarity_reads_${sex}.reads > low_similarity_reads_${sex}_1.fastq
        seqtk subseq ${reads2} low_similarity_reads_${sex}.reads > low_similarity_reads_${sex}_2.fastq
    done
    
    #Assemble each
    #high similarity Rickettsiella
    echo 'max_rd_len=101' > CONFIG_FILE_HIGH
    echo '[LIB]' >> CONFIG_FILE_HIGH
    echo 'avg_ins=225' >> CONFIG_FILE_HIGH
    echo 'reverse_seq=0' >> CONFIG_FILE_HIGH
    echo 'asm_flags=3' >> CONFIG_FILE_HIGH
    echo 'pair_num_cutoff=3' >> CONFIG_FILE_HIGH
    echo 'rank=1' >> CONFIG_FILE_HIGH
    echo 'q1=high_similarity_reads_M_1.fastq' >> CONFIG_FILE_HIGH
    echo 'q2=high_similarity_reads_M_2.fastq' >> CONFIG_FILE_HIGH
    # echo '[LIB]' >> CONFIG_FILE_HIGH
    # echo 'avg_ins=225' >> CONFIG_FILE_HIGH
    # echo 'reverse_seq=0' >> CONFIG_FILE_HIGH
    # echo 'asm_flags=3' >> CONFIG_FILE_HIGH
    # echo 'pair_num_cutoff=3' >> CONFIG_FILE_HIGH
    # echo 'rank=1' >> CONFIG_FILE_HIGH
    # echo 'q1=high_similarity_reads_F_1.fastq' >> CONFIG_FILE_HIGH
    # echo 'q2=high_similarity_reads_F_2.fastq' >> CONFIG_FILE_HIGH
    #Do the assembly
    SOAPdenovo-63mer all -s CONFIG_FILE_HIGH -K ${k} -d ${d1} -o high_similarity -b 2.0 -B 0.5 -p 16 -N 1600000
    
    #low similarity Rickettsiella
    echo 'max_rd_len=101' > CONFIG_FILE_LOW
    # echo '[LIB]' >> CONFIG_FILE_LOW
    # echo 'avg_ins=225' >> CONFIG_FILE_LOW
    # echo 'reverse_seq=0' >> CONFIG_FILE_LOW
    # echo 'asm_flags=3' >> CONFIG_FILE_LOW
    # echo 'pair_num_cutoff=3' >> CONFIG_FILE_LOW
    # echo 'rank=1' >> CONFIG_FILE_LOW
    # echo 'q1=low_similarity_reads_M_1.fastq' >> CONFIG_FILE_LOW
    # echo 'q2=low_similarity_reads_M_2.fastq' >> CONFIG_FILE_LOW
    echo '[LIB]' >> CONFIG_FILE_LOW
    echo 'avg_ins=225' >> CONFIG_FILE_LOW
    echo 'reverse_seq=0' >> CONFIG_FILE_LOW
    echo 'asm_flags=3' >> CONFIG_FILE_LOW
    echo 'pair_num_cutoff=3' >> CONFIG_FILE_LOW
    echo 'rank=1' >> CONFIG_FILE_LOW
    echo 'q1=low_similarity_reads_F_1.fastq' >> CONFIG_FILE_LOW
    echo 'q2=low_similarity_reads_F_2.fastq' >> CONFIG_FILE_LOW
    #Do the assembly
    SOAPdenovo-63mer all -s CONFIG_FILE_LOW -K ${k} -d ${d2} -o low_similarity -b 2.0 -B 0.5 -p 16 -N 1600000

    last_i=${i}
done

cd ..
mkdir final_reads
cp iteration${last_i}/*.fastq final_reads/

#Do final assembly for high_similarity
for final_k in 41 45 53 59 61 63 67
do
    for final_d in 2 3 4
    do
        cur_assembly=final_high_similarity_k${final_k}_d${final_d}
        mkdir ${cur_assembly}
        cd ${cur_assembly}
        #Assemble each
        echo 'max_rd_len=101' > CONFIG_FILE_HIGH
        echo '[LIB]' >> CONFIG_FILE_HIGH
        echo 'avg_ins=225' >> CONFIG_FILE_HIGH
        echo 'reverse_seq=0' >> CONFIG_FILE_HIGH
        echo 'asm_flags=3' >> CONFIG_FILE_HIGH
        echo 'pair_num_cutoff=3' >> CONFIG_FILE_HIGH
        echo 'rank=1' >> CONFIG_FILE_HIGH
        echo 'q1=../final_reads/high_similarity_reads_M_1.fastq' >> CONFIG_FILE_HIGH
        echo 'q2=../final_reads/high_similarity_reads_M_2.fastq' >> CONFIG_FILE_HIGH
        SOAPdenovo-63mer all -s CONFIG_FILE_HIGH -K ${final_k} -d ${final_d} -o high_similarity -b 2.0 -B 0.5 -p 16 -N 1600000
        cd ..
    done
done

#Do final assembly for low_similarity
for final_k in 41 45 53 59 61 63 67
do
    for final_d in 5 10 20
    do
        cur_assembly=final_low_similarity_k${final_k}_d${final_d}
        mkdir ${cur_assembly}
        cd ${cur_assembly}
        #Assemble each
        echo 'max_rd_len=101' > CONFIG_FILE_LOW
        echo '[LIB]' >> CONFIG_FILE_LOW
        echo 'avg_ins=225' >> CONFIG_FILE_LOW
        echo 'reverse_seq=0' >> CONFIG_FILE_LOW
        echo 'asm_flags=3' >> CONFIG_FILE_LOW
        echo 'pair_num_cutoff=3' >> CONFIG_FILE_LOW
        echo 'rank=1' >> CONFIG_FILE_LOW
        echo 'q1=../final_reads/low_similarity_reads_F_1.fastq' >> CONFIG_FILE_LOW
        echo 'q2=../final_reads/low_similarity_reads_F_2.fastq' >> CONFIG_FILE_LOW
        SOAPdenovo-63mer all -s CONFIG_FILE_LOW -K ${final_k} -d ${final_d} -o low_similarity -b 2.0 -B 0.5 -p 16 -N 1600000
        cd ..
    done
done


module load QUAST

#Run QUAST report for the high_similarity assemblies
quast_line='quast.py -t 16 -o quast_report_high_similarity --est-ref-size 1600000 -R ../rickettsiella_grylli.fasta -u --gene-finding'
#NOTE: Make sure the values in these for loops are the same as in the assembly section above
for final_k in 41 45 53 59 61 63 67
do
    for final_d in 2 3 4
    do
        quast_line=${quast_line}' final_high_similarity_k'${final_k}'_d'${final_d}'/high_similarity.contig'
    done
done
${quast_line}

#Run QUAST report for the low_similarity assemblies
quast_line='quast.py -t 16 -o quast_report_low_similarity --est-ref-size 1600000 -R ../rickettsiella_grylli.fasta -u --gene-finding'
#NOTE: Make sure the values in these for loops are the same as in the assembly section above
for final_k in 41 45 53 59 61 63 67
do
    for final_d in 5 10 20
    do
        quast_line=${quast_line}' final_low_similarity_k'${final_k}'_d'${final_d}'/low_similarity.contig'
    done
done
${quast_line}