#######################################
#Read in the BLAST results

column.titles <- c("qseqid",  "sseqid",  "evalue",  "bitscore", "length", "pident", "nident", "gaps", "qstart", "qend", "sstart", "send")
blast.results <- read.table("seed_contigs_blast_results.txt", header=F, col.names=column.titles)

#Filter BLAST results
blast.results <- blast.results[blast.results$evalue < 1e-20,]
blast.results$qseqid <- as.character(blast.results$qseqid)
blast.results$sseqid <- as.character(blast.results$sseqid)

#Add contig length data column
tempcrap <- unlist(strsplit(blast.results$qseqid, split="__len__"))
blast.results$contig_len <- as.numeric(tempcrap[seq(from=2, to=length(tempcrap), by=2)])

#Further filter by length
blast.results <- blast.results[blast.results$contig_len >= 200,]

#######################################
#Read in the coverage data

cov.results <- read.csv("per_contig_coverage_data.txt")

cov.results$contig <- as.character(cov.results$contig)

cov.results <- cov.results[cov.results$contig %in% blast.results$qseqid,]

#######################################
#Get coverage results for the Rickettsiella scaffolds

blast.results$contig_len <- rep(NA, nrow(blast.results))
blast.results$F_cov <- rep(NA, nrow(blast.results))
blast.results$M_cov <- rep(NA, nrow(blast.results))

for (r in 1:nrow(blast.results)) {
	cur.cov.row <- which(cov.results$contig == blast.results$qseqid[r])
	if (length(cur.cov.row) > 0) {
		blast.results$contig_len[r] <- cov.results$pos[cur.cov.row]
		blast.results$F_cov[r] <- cov.results$F_gDNA[cur.cov.row]
		blast.results$M_cov[r] <- cov.results$M_gDNA[cur.cov.row]
	}
}

###########################################

pdf(file="Rickettsiella_matches.pdf", width=8, height=4)

par(mfrow=c(1,2))

sim.color <- "#FF0000" #"#991155AA"
div.color <- "#0000FF" #"#119955BB"

pident.thresh <- 88

long.blast.results <- blast.results[blast.results$length > 200,]

sim.results <- long.blast.results[long.blast.results$pident > pident.thresh,]
div.results <- long.blast.results[long.blast.results$pident <= pident.thresh,]


###########################################

#Plot 1 -- matching position vs. pident

x.lab <- expression(paste("Position of match in ", italic("R. grylli"), " genome", sep=""))

par(mar=c(4,4,1,1))
plot(x=NULL, y=NULL, xlim=c(0,1.6e6), ylim=c(50, 100), xlab=x.lab, ylab="Percent identity")

for (i in 1:nrow(sim.results)) {
	lines(x=c(sim.results$sstart[i], sim.results$send[i]), y=rep(sim.results$pident[i], 2), col=sim.color, lwd=1.5)
}
for (i in 1:nrow(div.results)) {
	lines(x=c(div.results$sstart[i], div.results$send[i]), y=rep(div.results$pident[i], 2), col=div.color, lwd=1.5)
}
lines(x=c(-1e7, 1e7), y=rep(pident.thresh, 2), lty=2, col="#00000099")

text(x=0, y=100, "A", cex=1.5)

###########################################


f.log.cov.range <- range(log(long.blast.results$F_cov), finite=T)
m.log.cov.range <- range(log(long.blast.results$M_cov), finite=T)

plot(x=NULL, y=NULL, xlim=f.log.cov.range, ylim=m.log.cov.range, xlab="Log-coverage in female sample", ylab="Log-coverage in male sample")

points(x=log(sim.results$F_cov), y=log(sim.results$M_cov), col=sim.color, pch=16, cex=0.5)
points(x=log(div.results$F_cov), y=log(div.results$M_cov), col=div.color, pch=16, cex=0.5)

#Restore some important points that got obscured
restore.points <- sim.results[(log(sim.results$F_cov) > 6) & (log(sim.results$M_cov) < 2),]
points(x=log(restore.points$F_cov), y=log(restore.points$M_cov), col=sim.color, pch=16, cex=0.5)

text(x=f.log.cov.range[1], y=m.log.cov.range[2], "B", cex=1.5)


###########################################

dev.off()
