#!/bin/bash

#Parameters
reference=Rickettsiella_grylli.fasta
query=Rickettsiella_isopodorum_formatted.fasta
outputdir=dot_plot_isopodorum_grylli_200
chunk_size=200
min_size=5000
min_evalue=1e-3
reference_species=Rickettsiella_grylli
query_species=Rickettsiella_isopodorum

#Go to working directory
cd /N/dc2/scratch/chrichan/rickettsiella_dotplots

#Create output directory
mkdir ${outputdir}
cd ${outputdir}

#Convert query into a single-line fasta and re-format for later
awk '/^>/ {printf("\n%s\n",$0);next; } { printf("%s",$0);}  END {printf("\n");}' < ../${query} > ${query}.temp
awk '{if (length($0) > 1) print $0}' < ${query}.temp > ${query}.temp2
awk '/^>/ {printf("%s\n",$1); next;} {printf("%s\n",$0);} END {printf("\n");}' < ${query}.temp2 > ${query}.single_line
rm ${query}.temp
rm ${query}.temp2

#Divide query into chunks 
awk -v min_size=${min_size} -v chunk_size=${chunk_size} '/^>/ {cur_contig = substr($0, 2); next;} { if (length($0) >= min_size) { for (i = 1; i <= length($0); i += chunk_size) { cur_chunk = substr($0, i, chunk_size); if (length(cur_chunk) == chunk_size) {print ">" cur_contig "_chunk_" i; print cur_chunk} } } } ' < ${query}.single_line > ${query}.chunks_${chunk_size}

#Generate query contig lengths
awk '{if ($0 ~ ">") {printf("%s,", substr($0, 2))} else {if (length($0) >= 1) {print length($0)}}}' < ${query}.single_line > contig_lengths.txt

#Convert reference into single-line fasta and generate reference contig lengths
awk '/^>/ {printf("\n%s\n",$0);next; } { printf("%s",$0);}  END {printf("\n");}' < ../${reference} > ${reference}.temp
awk '{if (length($0) > 1) print $0}' < ${reference}.temp > ${reference}.temp2
awk '/^>/ {printf("%s\n",$1); next;} {printf("%s\n",$0);} END {printf("\n");}' < ${reference}.temp2 > ${reference}.single_line
rm ${reference}.temp
rm ${reference}.temp2
awk '{if ($0 ~ ">") {printf("%s,", substr($0, 2))} else {if (length($0) >= 1) {print length($0)}}}' < ${reference}.single_line > reference_contig_lengths.txt

#Do the BLAST searching
#ref=R_isopodorum_formatted.fasta
ref=../${reference}
chunks=${query}.chunks_${chunk_size}


#Use both blastn and tblastx for extra sensitivity
makeblastdb -in ${ref} -dbtype nucl
blastn -task blastn -query ${chunks} -db ${ref} -evalue ${min_evalue} -num_threads 8 -outfmt '6 qseqid sseqid sstart send length pident evalue bitscore' -num_alignments 1 > blastn_results_${chunk_size}.txt
tblastx -query ${chunks} -db ${ref} -evalue ${min_evalue} -num_threads 8 -outfmt '6 qseqid sseqid sstart send length pident evalue bitscore' -num_alignments 1 > tblastx_results_${chunk_size}.txt

#Now plot
module load gcc/4.7.2
module load R/3.1.1
Rscript --vanilla ../make_dot_plot.R ${chunk_size} blastn_results_${chunk_size}.txt tblastx_results_${chunk_size}.txt dot_plot_${chunk_size}.pdf islands_${chunk_size}.csv contig_lengths.txt reference_contig_lengths.txt ${min_size} ${query_species} ${reference_species}
