#Default vaules for parameters for debugging locally
# chunk.size <- 200
# blastn.file <- "dot_plot_isopodorum_grylli_200/blastn_results_200.txt"
# tblastx.file <- "dot_plot_isopodorum_grylli_200/tblastx_results_200.txt"
# output.file <- "dot_plot_isopodorum_grylli_200/dot_plot_200.pdf"
# island.file <- "dot_plot_isopodorum_grylli_200/island_coords_200.csv"
# contig.lengths.file <- "dot_plot_isopodorum_grylli_200/contig_lengths.txt"
# ref.contig.lengths.file <- "dot_plot_isopodorum_grylli_200/reference_contig_lengths.txt"
# min.size <- 5000
# x.label <- "Rickettsiella_isopodorum"
# y.label <- "Rickettsiella_grylli"

args <- commandArgs(trailingOnly = TRUE)

chunk.size <- as.numeric(args[1])
blastn.file <- args[2]
tblastx.file <- args[3]
output.file <- args[4]
island.file <- args[5]
contig.lengths.file <- args[6]
ref.contig.lengths.file <- args[7]
min.size <- as.numeric(args[8])
x.label <- sub("_", " ", args[9])
y.label <- sub("_", " ", args[10])

sprintf("chunk.size = %d", chunk.size)
sprintf("blastn.file = %s", blastn.file)
sprintf("tblastx.file = %s", tblastx.file)
sprintf("output.file = %s", output.file)
sprintf("island.file = %s", island.file)
sprintf("contig.lengths.file = %s", contig.lengths.file)
sprintf("ref.contig.lengths.file = %s", ref.contig.lengths.file)
sprintf("min.size = %d", min.size)
sprintf("x.label = %s", x.label)
sprintf("y.label = %s", y.label)

plot.colors <- c("#88228844", "#22CC2244") #For blastn and tblastx hits, respectively

########################################################################
########################################################################

#Read the BLAST results and compile/organize
blast.columns <- c("query", "subject", "sstart", "send", "length", "pident", "evalue", "bitscore")
blast.classes <- c("character", "character", "numeric", "numeric", "numeric", "numeric", "numeric", "numeric")
blastn.results <- read.table(blastn.file, header=F, col.names=blast.columns, colClasses=blast.classes)
tblastx.results <- read.table(tblastx.file, header=F, col.names=blast.columns, colClasses=blast.classes)
blastn.results$source <- 1
tblastx.results$source <- 2
blast.results <- rbind(blastn.results, tblastx.results)

split.queries <- strsplit(blast.results$query, "_chunk_")
contigs <- unlist(split.queries)[seq(from=1, by=2, to=length(split.queries)*2)]
chunks <- unlist(split.queries)[seq(from=2, by=2, to=length(split.queries)*2)]
blast.results$contig <- contigs
blast.results$chunk <- as.numeric(chunks)

blast.results$qstart <- blast.results$chunk

#Now need to translate query contig + coordinates into x-coordinates for plotting
contig.data <- read.csv(contig.lengths.file, col.names=c("contig", "length"), colClasses=c("character", "numeric"), header=F)
contig.data <- contig.data[contig.data$length >= min.size,]
contig.data$plot.start <- rep(NA, nrow(contig.data))
contig.data$plot.end <- rep(NA, nrow(contig.data))
contig.data$plot.start[1] <- 1
contig.data$plot.end[1] <- contig.data$length[1]
for (r in 2:nrow(contig.data)) {
	contig.data$plot.start[r] <- contig.data$plot.end[r-1] + 1
	contig.data$plot.end[r] <- contig.data$plot.start[r] + contig.data$length[r] - 1
}

#Translates a query contig coordinate into a plotting coordinate
get.plot.coord <- function(contig, contig.coord) {
	cur.contig.start <- contig.data[contig.data==contig,]
	result <- cur.contig.start$plot.start[1] + contig.coord - 1
	return(result)
}

#Translates a query plotting coordinate into a query contig
get.contig <- function(plot.coord) {
	match.row <- which((contig.data$plot.start <= plot.coord) & (contig.data$plot.end >= plot.coord))
	return(contig.data$contig[match.row])
}

#Translates a query plotting coordinate into a query contig coordinate
get.contig.coord  <- function(plot.coord) {
	match.row <- which((contig.data$plot.start <= plot.coord) & (contig.data$plot.end >= plot.coord))
	contig.start <- contig.data$plot.start[match.row]
	result <- plot.coord - contig.start + 1
	return(result)
}


#Perform some filtering of blast hits?
blast.results <- blast.results[blast.results$bitscore >= 50,]


#Translate query start positions into plotting positions
blast.results$plot.x <- rep(NA, nrow(blast.results))
for (r in 1:nrow(blast.results)) {
	blast.results$plot.x[r] <- get.plot.coord(blast.results$contig[r], blast.results$qstart[r])
}

#Translate reference coordinates into plotting positions for the y-axis
ref.contig.data <- read.csv(ref.contig.lengths.file, col.names=c("contig", "length"), colClasses=c("character", "numeric"), header=F)
ref.contig.data <- ref.contig.data[ref.contig.data$length >= min.size,]
ref.contig.data$plot.start <- rep(NA, nrow(ref.contig.data))
ref.contig.data$plot.end <- rep(NA, nrow(ref.contig.data))
ref.contig.data$plot.start[1] <- 1
ref.contig.data$plot.end[1] <- ref.contig.data$length[1]
for (r in 2:nrow(ref.contig.data)) {
	ref.contig.data$plot.start[r] <- ref.contig.data$plot.end[r-1] + 1
	ref.contig.data$plot.end[r] <- ref.contig.data$plot.start[r] + ref.contig.data$length[r] - 1
}
#Translates a reference contig coordinate into a plotting coordinate
get.plot.coord.ref <- function(contig, contig.coord) {
	cur.contig.start <- ref.contig.data[ref.contig.data==contig,]
	result <- cur.contig.start$plot.start[1] + contig.coord - 1
	return(result)
}
#Translates a reference plotting coordinate into a reference contig
get.contig.ref <- function(plot.coord) {
	match.row <- which((ref.contig.data$plot.start <= plot.coord) & (ref.contig.data$plot.end >= plot.coord))
	return(ref.contig.data$contig[match.row])
}
#Translates a reference plotting coordinate into a reference contig coordinate
get.contig.coord.ref  <- function(plot.coord) {
	match.row <- which((ref.contig.data$plot.start <= plot.coord) & (ref.contig.data$plot.end >= plot.coord))
	contig.start <- ref.contig.data$plot.start[match.row]
	result <- plot.coord - contig.start + 1
	return(result)
}
blast.results$plot.y <- rep(NA, nrow(blast.results))
for (r in 1:nrow(blast.results)) {
	blast.results$plot.y[r] <- get.plot.coord.ref(blast.results$subject[r], blast.results$sstart[r])
}


pdf(file=output.file, width=6, height=6)

par(mar=c(4,4,1,1))
plot(x=blast.results$plot.x, y=blast.results$plot.y, pch=16, col=plot.colors[blast.results$source], cex=0.5, xlab=x.label, ylab=y.label, xaxs="i", yaxs="i")

#, xaxs="i", yaxs="i"

#Add the contig borders
for (c in 1:nrow(contig.data)) {
	lines(x=rep(contig.data$plot.end[c]+0.5, 2), y=c(-1e8, 1e8), col="#00000055")
}

for (c in 1:nrow(ref.contig.data)) {
	lines(y=rep(ref.contig.data$plot.end[c]+0.5, 2), x=c(-1e8, 1e8), col="#00000055")
}


#Look for parts of query (x-axis) that have no hits in reference (y-axis)
island.allocation <- 100
blank.island <- rep(NA, island.allocation)
island.data <- data.frame(contig=blank.island, start=blank.island, end=blank.island, plot.start=blank.island, plot.end=blank.island)
cur.island <- 1
length.thresh <- 4000
needed.windows <- length.thresh / chunk.size

#c <- 14
for (c in 1:nrow(contig.data)) {
	cur.contig <- contig.data$contig[c]
	cur.contig.length <- contig.data$length[c]
	if (cur.contig.length >= length.thresh) {
		
		#Step 1: for the current contig, find any chunks that had no BLAST hits in the reference
		cur.num.chunks <- floor(cur.contig.length / chunk.size)
		cur.max.contig.coord <- cur.num.chunks * chunk.size
		cur.chunk.data <- data.frame(num=1:cur.num.chunks, start=seq(from=1, to=cur.max.contig.coord, by=chunk.size))
		cur.chunk.data$end <- cur.chunk.data$start + chunk.size - 1
		cur.chunk.data$match <- rep(FALSE, cur.num.chunks)
		cur.blast.results <- blast.results[blast.results$contig == cur.contig,]
		cur.chunk.data$match <- (cur.chunk.data$start %in% cur.blast.results$chunk)		
		nonmatching.rows <- which(!cur.chunk.data$match)
		
		#Step 2: collapse blocks of consecutive chunks that did not have BLAST hits in the reference
		if (length(nonmatching.rows) >= needed.windows) {
			#Initialize with the first block
			cur.island.starts <- cur.chunk.data$start[nonmatching.rows[1]]
			cur.island.ends <- NULL
			#Loop through remaining non-matching chunks
			for (r in 2:length(nonmatching.rows)) {
				#If the current non-matching chunk is not contiguous with the previous one, then start a new blokc
				if (cur.chunk.data$start[nonmatching.rows[r]] != (cur.chunk.data$end[nonmatching.rows[r-1]]+1) ) {
					cur.island.ends <- c(cur.island.ends, (cur.chunk.data$end[nonmatching.rows[r-1]]))
					cur.island.starts <- c(cur.island.starts, cur.island.starts <- cur.chunk.data$start[nonmatching.rows[r]])
				}
			}
			cur.island.ends <- c(cur.island.ends, (cur.chunk.data$end[nonmatching.rows[length(nonmatching.rows)]]) )#nonmatching.rows[length(nonmatching.rows)])
			cur.island.data <- data.frame(start = cur.island.starts, end = cur.island.ends)
			cur.island.data$length <- (cur.island.data$end - cur.island.data$start + 1)
			cur.island.data <- cur.island.data[cur.island.data$length >= length.thresh,]
			if (nrow(cur.island.data) >= 1) {
				for (i in 1:nrow(cur.island.data)) {
					island.data$contig[cur.island] <- cur.contig
					island.data$start[cur.island] <- cur.island.data$start[i]
					island.data$end[cur.island] <- cur.island.data$end[i]
					island.data$plot.start[cur.island] <- get.plot.coord(cur.contig, island.data$start[cur.island])
					island.data$plot.end[cur.island] <- get.plot.coord(cur.contig, island.data$end[cur.island])
					cur.island <- cur.island + 1
				}
			}
		}
	}
}

island.data <- island.data[!is.na(island.data$contig),]
island.data$length <- island.data$end - island.data$start + 1

#Now plot the "islands"
for (r in 1:nrow(island.data)) {
	rect(xleft=island.data$plot.start[r], xright=island.data$plot.end[r], ybottom = -1e9, ytop=1e9, border=NA, col="#AA000066")
}




dev.off()


#Now save the "island" coordinates

write.csv(file=island.file, island.data, row.names=F, quote=F)